@@ -4,7 +4,7 @@ from itertools import islice, chain, tee, groupby, \
 from collections import defaultdict, deque, Sequence
 
 from .cross import map as _map, filter as _filter, ifilter as _ifilter, imap as _imap, \
-                   izip, ifilterfalse, xrange, PY2
+                   izip, ifilterfalse, xrange, PY2, PY3
 from .primitives import EMPTY
 from .types import is_seqcont
 from .funcs import partial
@@ -18,7 +18,7 @@ __all__ = [
     'concat', 'iconcat', 'chain', 'cat', 'icat', 'flatten', 'iflatten', 'mapcat', 'imapcat',
     'izip', 'interleave', 'interpose', 'distinct', 'idistinct',
     'dropwhile', 'takewhile', 'split', 'isplit', 'split_at', 'isplit_at', 'split_by', 'isplit_by',
-    'group_by', 'group_by_keys', 'group_values', 'count_by',
+    'group_by', 'group_by_keys', 'group_values', 'count_by', 'count_reps',
     'partition', 'ipartition', 'chunks', 'ichunks', 'ipartition_by', 'partition_by',
     'with_prev', 'with_next', 'pairwise',
     'ireductions', 'reductions', 'isums', 'sums',
@@ -287,6 +287,14 @@ def count_by(f, seq):
     return result
 
 
+# Or count_unique() after all?
+def count_reps(seq):
+    result = defaultdict(int)
+    for item in seq:
+        result[item] += 1
+    return result
+
+
 # For efficiency we use separate implementation for cutting sequences (those capable of slicing)
 def _icut_seq(drop_tail, n, step, seq):
     limit = len(seq)-n+1 if drop_tail else len(seq)
@@ -309,8 +317,7 @@ def _icut(drop_tail, n, step, seq=EMPTY):
     if seq is EMPTY:
         step, seq = n, step
     # NOTE: range() is capable of slicing in python 3,
-    #       so this implementation could be updated
-    if isinstance(seq, Sequence) and not isinstance(seq, xrange):
+    if isinstance(seq, Sequence) and (PY3 or not isinstance(seq, xrange)):
         return _icut_seq(drop_tail, n, step, seq)
     else:
         return _icut_iter(drop_tail, n, step, seq)
